

#include "Arduino.h"
#include "serialcom.h"
#include "sw_uart.h"
#include "cc1101.h"

#define  HEADMASTER 0xAA
#define  POINTERSELECTION1 0xA1 
#define  POINTERSELECTION 0xA3          //Set Read/Write address bits 15:0
#define  LECTURECOMMANDE 0xE3           //Read command
#define  ECRITURECOMMANDE 0xD3          //write command
#define  ADDRIFSCALE 0x018C               
#define  ADDRVFSCALE 0x0189
#define  ADDRVTARGET 0x0072
#define  ADDRITARGET 0x00B4
#define  ADDRT_TARGET 0x013E
#define  ADDRBUCKET_L 0x019B
#define  ADDRBUCKET_H 0x019E
#define  ADDRCOMMANDE 0x0000
#define  ADDRCONFIG 0X006F
#define FSV 667
#define FSI 63

//a voir
#define VA 0x0099
#define IA 0xCC
#define VA_RMS 0x0081
#define IA_RMS 0x00BA
#define WATT_A 0x00E1
#define VAR_A 0x00F3
#define VA_A 0x00EA
#define PFA 0x012F
#define TEMPC 0x013B
#define PA_POS_CNT 0x01AD
#define FSP 42021

//Packet maitre (microcontroleur)
typedef struct MPACKET MPACKET;
struct MPACKET
{
    //synchronisation 
    uint8_t header; 

    //longueur du paquet
    uint8_t count;
    
    //commande
    uint8_t payload;

    //adresse du registre premier octet 
    uint8_t Ladresse;
    
    //adresse du registre deuxiem octet
    uint8_t Hadresse;
    
    //commande lecture/ecriture
    uint8_t com2;
    //used for writing into the register    
     //dataL;
    uint8_t data1;
    //data
    uint8_t data2;
    //dataH
    uint8_t data3;

    //checksum modulo 256
    uint8_t checksum;
};

//Packet esclave (maxim78m6610)
typedef struct SPACKET SPACKET;
struct SPACKET
{
    //synchronisation 
    uint8_t acknowledge; 

    //longueur du paquet
    uint8_t count;
    
    //dataL;
    uint8_t data1;
    //data
    uint8_t data2;
    //dataH
    uint8_t data3;
    //checksum modulo 256
    uint8_t checksum;
};

typedef struct calibRegister CalibRegister;
struct calibRegister
{
    uint32_t Voltage;
    uint32_t Current;
    uint32_t Temp;
};

typedef struct packet CALIBPacket;
struct packet
{
    //uint16_t add;
    uint8_t voltage;
    uint8_t current;
    uint8_t temp;
};


//permet de constituer une trame de selection
void trame_master_select(MPACKET *masterpacket, uint8_t commande,uint16_t WordAddr,uint8_t commande2, uint8_t *ValueArray);

//permet de constituer une trame de commande
void trame_master_commande(MPACKET *masterpacket, uint8_t commande);

//permet d'envoyer une trame en provenance du maitre vers l'esclave
void Send_master(MPACKET *masterpacket);

//attente d'un acknowledge répondant à une trame de selection
boolean wait_acknowledge_without_data(SPACKET *slavepacket);

//attente d'un acknowledge répondant à une trame de commande
boolean wait_acknowledge_and_data(SPACKET *slavepacket);

//réception d'une trame envoyé par l'éscalve(maxim) et reçu par le maitre(panstamp)
void receiv_master(SPACKET *slavepacket);

//permet d'afficher sur le terminal la trame reçu par le maitre(panstamp)
void affichagetrame(SPACKET *slavepacket);
//processus de calibration 
void calibrationprocess(MPACKET *masterpacket,SPACKET *slavepacket,CALIBPacket *valuecalib);

uint32_t floatToInt32(float *value);

uint8_t *getBytesValue(size_t value);

float calcRealValue(uint8_t HByteaddress, uint8_t LByteAddress, uint8_t HByteValue, uint8_t MByteValue, uint8_t LByteValue);

void targetvalue(MPACKET *masterpacket,SPACKET *slavepacket,CALIBPacket *valuecalib);

void lectureMaxim();