/*****************************************
Filename  : sw_uart_config.h
Author    : Prashant Mehta
Date	  : 26-06-2009
******************************************/
/*                   
*******************************************************************************************************************
*  Header file for configuring SOFTWARE UART     								  *
*  Timer 0 is set to 3 times the required baud rate because data sampling has to be done 3 times per bit	  *
*  Here Timer 0 of AtMega128 is used. Change the timer registers as per used uC					  *
*  UART can be configured using ATMEGA128 like UART control registers						  *
*  Any port pin can be made into Tx and  Rx pin by changing in macros below					  *
*  5,6,7,8 bits Tx and Rx possible by this s/w UART								  *
*  1 or 2 Stop bits as pre-defined by user									  *
*  Possible to use parity bit (even or odd) along with data frame						  *
*******************************************************************************************************************
*/

#include <avr/io.h>
#include <avr/interrupt.h>
#include <stdlib.h>
#include <stdio.h>
#include <avr/io.h>
#include <avr/pgmspace.h>
#include <stdint.h>
volatile long int 				baudrate;
#define EVEN 0
#define ODD 1

#define NO 0
#define YES 1
/*************************************** PORT to be used for Tx and Rx *********************************************/
#define UART_RXPIN   PINC
#define UART_RXDDR   DDRC
#define UART_RXBIT   PC5
#define UART_RXPORT  PORTC

#define UART_TXPORT  PORTC
#define UART_TXDDR   DDRC
#define UART_TXBIT   PC4
/********************************************************************************************************************/

/************************* Define Oscillator frequency and required baud rate for UART here *************************/
#define CPU_CLOCK_HZ 8000000
#define BAUD_RATE 9600
/********************************************************************************************************************/

/**************************** Define number of data bits and number of stop bits here *******************************/
#define NUM_OF_DATABITS 8
#define NUM_OF_STOPBITS 1
/*********************************************use for timer***********************************************************************/
#define SOFTUART_T_COMP_REG OCR0A
#define SOFTUART_T_CONTR_REGA TCCR0A
#define SOFTUART_T_CONTR_REGB TCCR0B
#define SOFTUART_T_CNT_REG TCNT0
#define SOFTUART_T_INTCTL_REG TIMSK0
#define SOFTUART_CMPINT_EN_MASK (1 << OCIE0A)
#define SOFTUART_CTC_MASKA (1 << WGM01)
#define SOFTUART_CTC_MASKB (0)
//prescale de 8
#define SOFTUART_PRESC_MASKA (0)
#define SOFTUART_PRESC_MASKB (1 << CS01)
//prescale de 1
//#define SOFTUART_PRESC_MASKA (0)
//#define SOFTUART_PRESC_MASKB (1 << CS00)

/************************************ Make U2X2 1 to double Baud rate ***********************************************/
#define U2X2 0
/********************************************************************************************************************/

/**************************** Define if you want to use Parity bit in SW UART here *********************************/
/****************************** If using parity bit define whether EVEN or ODD Parity *******************************/
#define PARITY_BIT NO
#define PARITY ODD 
/********************************************************************************************************************/
